<?xml version="1.0" encoding="windows-1251"?>
<!DOCTYPE xsl:stylesheet [
    <!ENTITY nbsp "&#160;">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/TR/xhtml1/strict">

<xsl:output method="html" encoding="windows-1251" />

<xsl:strip-space elements="lecture title annotation section list table tr footnote"/>
<xsl:preserve-space elements="p example quote keyword-context code keyword ref sub sup em"/>

    <xsl:template match="/">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="lecture">
            <xsl:apply-templates select="section|tasks|page-break"/>
    </xsl:template>

    <xsl:template match="lecture/section" priority="2">
        <h3><xsl:apply-templates select="title" mode="title"/></h3>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="lecture/section/section" priority="2">
        <h4><xsl:apply-templates select="title" mode="title"/></h4>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="lecture/section/section/section" priority="2">
        <h5><xsl:apply-templates select="title" mode="title"/></h5>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="section" priority="1">
        <h6><xsl:apply-templates select="title" mode="title"/></h6>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="title" mode="title">
        <xsl:apply-templates/>
    </xsl:template>


    <xsl:template match="p">
        <p><xsl:apply-templates/></p>
    </xsl:template>

    <xsl:template match="sup">
        <sup><xsl:apply-templates/></sup>
    </xsl:template>

    <xsl:template match="sub">
        <sub><xsl:apply-templates/></sub>
    </xsl:template>

<xsl:template match="em">
        <xsl:choose>
        <xsl:when test="not(@type)">
	    <b><xsl:apply-templates/></b>
	</xsl:when>
	<xsl:otherwise>
	<span class="xml_em_{@type}"><xsl:apply-templates/></span>
        </xsl:otherwise>
	</xsl:choose>
</xsl:template>

    <xsl:template match="footnote">
        <xsl:value-of select="term"/>
<sup><a href="{@url}" target="_blank" onClick="window.open('{@url}','','menubar=no,scrollbars=yes,resizable=yes');return false;" class="objectName"><xsl:value-of select="@footnote_cnt_on_page"/>)</a></sup>
    </xsl:template>

<xsl:template match="quote">
    <blockquote><xsl:apply-templates/>
    <xsl:if test="@author">
    <div class="xml_quote_author"><xsl:value-of select="@author"/></div>
    </xsl:if>
</blockquote>
</xsl:template>



    <xsl:template match="code">
        <span class="texample"><xsl:apply-templates/></span>
    </xsl:template>

    <xsl:template match="example">
        <xsl:if test="@number">
        <a name="{@aname}"></a>
        </xsl:if>
        <div class="example"><xsl:if test="not(@visible='no')"><pre><xsl:apply-templates/></pre></xsl:if>
        <xsl:if test="@number">
        <span class="objectName">
            <xsl:choose>
            <xsl:when test="@type='example'">
             
            </xsl:when>
            <xsl:when test="@type='listing'">
             
            </xsl:when>
            </xsl:choose>
            <xsl:value-of select="@number"/>.
            <xsl:if test="@title">
            <xsl:value-of select="@title"/>
            </xsl:if>
            (<a href="{@url_html}" target="_blank" onClick="window.open('{@url_html}','','menubar=no,scrollbars=yes,resizable=yes{@popup_size}');return false;" class="objectName">html</a>,
            <a href="{@url_txt}" target="_blank" onClick="window.open('{@url_txt}','','menubar=no,scrollbars=yes,resizable=yes{@popup_size}');return false;" class="objectName">txt</a>)
            </span>
        </xsl:if>
    </div>
    </xsl:template>

    <xsl:template match="li">
        <li><xsl:apply-templates/></li>
    </xsl:template>

    <xsl:template match="list">
        <xsl:choose>
        <xsl:when test="@type='number'">

	        <xsl:choose>
		        <xsl:when test="@start">
				<xsl:element name="ol">
					<xsl:attribute name="start"><xsl:value-of select="@start"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
		        </xsl:when>
		        <xsl:otherwise>
		            <ol><xsl:apply-templates/></ol>
		        </xsl:otherwise>
		</xsl:choose>

        </xsl:when>
        <xsl:otherwise>
            <ul><xsl:apply-templates/></ul>
        </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="keyword">
        <xsl:choose>
        <xsl:when test="@type='def'">
            <span class="keyword_def"><xsl:apply-templates/></span>
        </xsl:when>
        <xsl:otherwise>
            <span class="keyword"><xsl:apply-templates/></span>
        </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="image">
        <xsl:choose>

        <xsl:when test="@type='inline'">
        <xsl:element name="img">
        <xsl:attribute name="src"><xsl:value-of select="@src"/></xsl:attribute>
        <xsl:attribute name="alt"><xsl:value-of select="@title"/></xsl:attribute>
        <xsl:if test="@width">
            <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
        </xsl:if>
        <xsl:if test="@height">
            <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
        </xsl:if>
        </xsl:element>
        </xsl:when>


        <xsl:otherwise>
        <p align="left">
        <a name="{@aname}"></a>
        <xsl:element name="img">
        <xsl:attribute name="src"><xsl:value-of select="@src"/></xsl:attribute>
        <xsl:attribute name="alt"><xsl:value-of select="@title"/></xsl:attribute>
        <xsl:if test="@width">
            <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
        </xsl:if>
        <xsl:if test="@height">
            <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
        </xsl:if>
        </xsl:element><br/>
        <xsl:if test="@full-size">
            <a href="{@full-size}" target="_blank" onClick="window.open('{@full-size}','','menubar=no,scrollbars=yes,resizable=yes{@popup_size}');return false;" class="objectName"> </a>
            <br/>
        </xsl:if>
        <xsl:if test="@number">
        <b>. <xsl:value-of select="@number"/>.</b>&nbsp;
        </xsl:if>
        <xsl:if test="@title">
        <xsl:value-of select="@title"/>
        </xsl:if>
        </p>
        </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="ref/ref-name">
        <xsl:value-of select="../@ref_name"/>
    </xsl:template>

    <xsl:template match="ref">

		<xsl:choose>
		<xsl:when test="@icon != ''">
			<a target="_blank" href="{@url}"><img border="0" src="http://www.intuit.ru/img/icons/{@icon}.gif" /></a>&nbsp;<xsl:if test="not(.='')"><a target="_blank" href="{@url}"><xsl:apply-templates /></a></xsl:if>
		</xsl:when>
		<xsl:otherwise>

        <xsl:choose>
            <xsl:when test="not(.='')"><xsl:choose>
            <xsl:when test="(@type = 'literature') or (@type = 'url')">
                            <a target="_blank" href="{@url}"><xsl:apply-templates/></a>
            </xsl:when>
            <xsl:otherwise>
                            <a href="{@url}"><xsl:apply-templates/></a>
            </xsl:otherwise>
                </xsl:choose></xsl:when>
                <xsl:otherwise><xsl:choose>
                <xsl:when test="@type = 'example'">
                <a href="{@url}"> <xsl:value-of select="@src"/></a>
                </xsl:when>
                <xsl:when test="@type = 'literature'">
                <a target="_blank" href="{@url}">[<xsl:value-of select="@ref_name"/>]</a>
                </xsl:when>
                <xsl:when test="@type = 'image'">
                <a href="{@url}">. <xsl:value-of select="@src"/></a>
                </xsl:when>
                <xsl:when test="@type = 'table'">
                <a href="{@url}"> <xsl:value-of select="@src"/></a>
                </xsl:when>
                <xsl:when test="@type = 'lecture'">
                <a href="{@url}"><xsl:value-of select="@ref_name"/></a>
                </xsl:when>
                <xsl:when test="@type = 'course'">
                <a href="{@url}"><xsl:value-of select="@ref_name"/></a>
                </xsl:when>
            <xsl:otherwise>
			<a target="_blank" href="{@url}"><xsl:value-of select="@src"/></a>
            </xsl:otherwise></xsl:choose>
                </xsl:otherwise>
                </xsl:choose>

		</xsl:otherwise>
		</xsl:choose>	


    </xsl:template>



    <!-- tables -->
    <xsl:template match="table">
    <div class="xml_table_env">
    <a name="{@aname}"></a>
        <table border="0" class="xml_table" cellpadding="2" cellspacing="1">
        <xsl:if test="@number or caption!=''">
            <caption>
                    <xsl:if test="@number">
                     <xsl:value-of select="@number"/>.
                    </xsl:if>
                    <xsl:value-of select="caption"/>
		</caption>
        </xsl:if>
        <xsl:for-each select="tr">
            <tr>
                <xsl:apply-templates/>
            </tr>
        </xsl:for-each>
        </table>
    </div>
    </xsl:template>

    <xsl:template match="th">
        <xsl:element name="th">
            <xsl:if test="@colspan">
                <xsl:attribute name="colspan"><xsl:value-of select="@colspan"/></xsl:attribute>
            </xsl:if>
            <xsl:if test="@rowspan">
                <xsl:attribute name="rowspan"><xsl:value-of select="@rowspan"/></xsl:attribute>
            </xsl:if>
            <xsl:choose>
            <xsl:when test="../../@type='blank'">
            </xsl:when>
            <xsl:otherwise>
            <xsl:attribute name="bgcolor">#d8d8d8</xsl:attribute>
            </xsl:otherwise>
            </xsl:choose>
            <xsl:apply-templates/>
        </xsl:element>
    </xsl:template>

    <xsl:template match="td">
        <xsl:element name="td">
            <xsl:if test="@colspan">
                <xsl:attribute name="colspan"><xsl:value-of select="@colspan"/></xsl:attribute>
            </xsl:if>
            <xsl:if test="@rowspan">
                <xsl:attribute name="rowspan"><xsl:value-of select="@rowspan"/></xsl:attribute>
            </xsl:if>
            <xsl:choose>
            <xsl:when test="../../@type='blank'">
            </xsl:when>
            <xsl:otherwise>
            <xsl:attribute name="bgcolor">#eaeaea</xsl:attribute>
            </xsl:otherwise>
            </xsl:choose>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:apply-templates/>
        </xsl:element>
    </xsl:template>
    <!-- /tables -->

    <xsl:template match="page-break">

    --PAGE-BREAK--

    </xsl:template>

    <xsl:template match="keyword-context">
    <a name="{@aname}"></a>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="insert-symbol">
      <img src="http://www.intuit.ru/img/symbols/{@name}.gif" width="{@width}" height="{@height}" border="0" alt="" style="position: relative; top: 2px" />
    </xsl:template>

    <xsl:template match="vector">
      <span class="vector"><xsl:apply-templates/></span>
    </xsl:template>


















    <xsl:template match="form">
	<table cellspacing="1" cellpading="1" border="0" width="100%">
	<form target="_blank" method="POST" action="/user/intel-form/">
<input type="hidden" name="cid" value="{@cid}"/>
<input type="hidden" name="lecture_num" value="{@lecture_num}"/>
<input type="hidden" name="code" value="{@code}"/>
        <tr><td><xsl:apply-templates mode="form"/></td></tr>
%IFNOT(IS_CD)%
	<tr><td><input type="submit" class="inputlo" value=""/></td></tr>
%ENDIFNOT(IS_CD)%
	</form>
	</table>
    </xsl:template>

    <xsl:template match="job" mode="form">
		<xsl:apply-templates/>
		<br/>
    </xsl:template>

    <xsl:template match="fields" mode="form">
	<xsl:apply-templates mode="form"/>
    </xsl:template>

    <xsl:template match="field" mode="form">
	<xsl:apply-templates mode="form"/>
	<br/>
    </xsl:template>

    <xsl:template match="help" mode="form">
    </xsl:template>

    <xsl:template match="name" mode="form">
    </xsl:template>

    <xsl:template match="name" mode="form_input">
	<xsl:apply-templates/>
	<br/>
    </xsl:template>
    <xsl:template match="name" mode="form_input_left">
	<xsl:apply-templates/>
	<br/>
    </xsl:template>

    <xsl:template match="help" mode="form_input">
	<br/>
	<span class="help">
	<xsl:apply-templates/>
	</span>
    </xsl:template>


    <xsl:template match="input" mode="form">
<input type="hidden" name="__names" value="{@name}"/>
	<xsl:choose>
	<xsl:when test="@type='textarea'">
		<xsl:apply-templates select="../name" mode="form_input" />
		<textarea name="{@name}" cols="64" rows="{@height}"><xsl:value-of select="@value"/></textarea>
		<xsl:apply-templates select="../help" mode="form_input" />
	</xsl:when>
	<xsl:when test="@type='checkbox'">
		<input name="{@name}" style="margin-left: 0px;" type="checkbox"/>&nbsp;
		<xsl:apply-templates select="../name" mode="form_input_left" />
		<xsl:apply-templates select="../help" mode="form_input" />
	</xsl:when>
	<xsl:when test="@type='text'">
		<xsl:apply-templates select="../name" mode="form_input" />
		<input name="{@name}" size="64" value="{@value}" type="text"/>&nbsp;
		<xsl:apply-templates select="../help" mode="form_input" />
	</xsl:when>
	<xsl:when test="@type='select'">
		<xsl:apply-templates select="../name" mode="form_input" />
		<select name="{@name}">
		<xsl:apply-templates mode="form_select"/>
		</select>
		<xsl:apply-templates select="../help" mode="form_input" />
	</xsl:when>
	<xsl:when test="@type='radio'">
		<xsl:apply-templates select="../name" mode="form_input" />
		<xsl:apply-templates select="../help" mode="form_input" />
		<br/>
		<div style="margin-left: 10px;">
		<xsl:apply-templates mode="form_radio"/>
		</div>
	</xsl:when>
        <xsl:otherwise>
            	<input name="{@name}" type="{@type}" size="{@size}"/>
        </xsl:otherwise>
	</xsl:choose>
    </xsl:template>


<xsl:template match="option" mode="form_select">
<option value="{@value}"><xsl:apply-templates/></option>
</xsl:template>


<xsl:template match="option" mode="form_radio">
<input type="radio" name="{../@name}" value="{@name}" />
<xsl:apply-templates/>
<br/>
</xsl:template>


<xsl:template match="form-text" mode="form">
<p><xsl:apply-templates/></p>
</xsl:template>




<xsl:template match="inset">
<p>
<table border="1" cellpadding="20" cellspacing="0" width="100%"><tr>
<td valign="top"> 
<xsl:if test="@icon">
<img align="left" valign="top" src="{@icon}"/>
</xsl:if>
<xsl:apply-templates/>
</td>
</tr></table>
</p>
</xsl:template>


<xsl:template match="accent">
<table 
	border="0"
	style="border-collapse: collapse; display: inline; margin: 0em 0em 0em; vertical-align: text-bottom; text-align: center" cellpadding="0" cellspacing="0">
<tr><td class="texample" align="center">
<img src="/img/accent/{@name}.gif" width="8" height="4" border="0" alt="&amp;{@name};" style="position: relative; top: 6px; left: 4px" />
</td></tr>
<tr><td><span class="texample"><xsl:apply-templates/></span></td></tr>
</table>
</xsl:template>

<xsl:template match="math">

        <xsl:element name="img">
        <xsl:attribute name="src">/img/tex/<xsl:value-of select="@code"/>.png</xsl:attribute>
        <xsl:attribute name="alt"><xsl:value-of select="@tex"/></xsl:attribute>
        <xsl:if test="@width">
            <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
        </xsl:if>
        <xsl:if test="@height">
            <xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
        </xsl:if>
        </xsl:element>

</xsl:template>


    <xsl:template match="*" />
</xsl:stylesheet>
